// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef ANALITZA_VERSION_H
#define ANALITZA_VERSION_H

#define ANALITZA_VERSION_STRING "9.0.0"
#define ANALITZA_VERSION_MAJOR 9
#define ANALITZA_VERSION_MINOR 0
#define ANALITZA_VERSION_PATCH 0
#define ANALITZA_VERSION ((9<<16)|(0<<8)|(0))

#endif
